photosgallery/viewframework/commandhandlers/commoncommandhandlers/inc/glxcommandhandleraiwshowmap.h
branchRCL_3
changeset 25 191387a8b767
parent 3 9a9c174934f5
--- a/photosgallery/viewframework/commandhandlers/commoncommandhandlers/inc/glxcommandhandleraiwshowmap.h	Wed Apr 14 15:57:24 2010 +0300
+++ b/photosgallery/viewframework/commandhandlers/commoncommandhandlers/inc/glxcommandhandleraiwshowmap.h	Tue Apr 27 16:37:53 2010 +0300
@@ -42,17 +42,19 @@
     {
 public:
     /**
      * Two-phase constructor
      * @param aMediaListProvider object that provides the media list
      * @param aMenuResource The menu resource that the AIW command will be 
      *          implented in
      * @return Fully constructed command handler
      * @warning ConstructL of base class is called. If ConstructL is 
      *          implemented in this class, then care must be taken to call 
      *          CGlxCommandHandlerAiwBase::ConstructL
      */
 	IMPORT_C static CGlxCommandHandlerAiwShowMap* NewL(
-	    MGlxMediaListProvider* aMediaListProvider, TInt aMenuResource);
+			MGlxMediaListProvider* aMediaListProvider, TInt aMenuResource,
+			const TDesC& aFileName);
 	
     /**
      * Perform any actions needed before the options menu is displayed.
@@ -42,17 +42,19 @@
 public:
     /**
-     * Two-phase constructor
-     * @param aMediaListProvider object that provides the media list
-     * @param aMenuResource The menu resource that the AIW command will be 
-     *          implented in
-     * @return Fully constructed command handler
-     * @warning ConstructL of base class is called. If ConstructL is 
-     *          implemented in this class, then care must be taken to call 
-     *          CGlxCommandHandlerAiwBase::ConstructL
-     */
+	 * Two-phase constructor
+	 * @param aMediaListProvider object that provides the media list
+	 * @param aMenuResource The menu resource that the AIW command will be 
+	 *          implented in
+	 * @param aFileName resource file
+	 * @return Fully constructed command handler
+	 * @warning ConstructL of base class is called. If ConstructL is 
+	 *          implemented in this class, then care must be taken to call 
+	 *          CGlxCommandHandlerAiwBase::ConstructL
+	 */
 	IMPORT_C static CGlxCommandHandlerAiwShowMap* NewL(